Computes the ELBO:
Arguments
- flow
A flow model created by
makeflow().- Qobs
Observed empirical distribution (probability vector).
- pxgivenz
A function mapping a latent vector z to a categorical pmf.
- nmc
Number of Monte Carlo samples.
Computes the ELBO:
A flow model created by makeflow().
Observed empirical distribution (probability vector).
A function mapping a latent vector z to a categorical pmf.
Number of Monte Carlo samples.