Same structure as makeneurolik(), but with a different default separation
parameter. This can be used to model simple biological switching systems
or coarse-grained gene expression states.
Same structure as makeneurolik(), but with a different default separation
parameter. This can be used to model simple biological switching systems
or coarse-grained gene expression states.