Learn R Programming

rareflow (version 0.1.0)

makebiolik: Biological Two-Separator Likelihood

Description

Same structure as makeneurolik(), but with a different default separation parameter. This can be used to model simple biological switching systems or coarse-grained gene expression states.

Usage

makebiolik(a = 0.2)

Value

A function mapping a latent vector z to a probability vector.

Arguments

a

Separation parameter controlling the spacing between the two logits.