A unified constructor for all flow models in the rareflow package.
This function dispatches to the appropriate flow implementation
based on the flowtype argument.
Usage
makeflow(flowtype, params = list())A unified constructor for all flow models in the rareflow package.
This function dispatches to the appropriate flow implementation
based on the flowtype argument.
makeflow(flowtype, params = list())