A unified constructor for all flow models in the rareflow package.
This function dispatches to the appropriate flow implementation
based on the flowtype argument.
Usage
makeflow(flowtype, params = list())
Value
A flow model object with methods:
sampleq(n)
logq(z0)
applyflow(z0)
Arguments
flowtype
Character string specifying the flow type.
params
A named list of parameters required by the chosen flow.